#!/bin/bash
#################################################################
# Earthquakes script
version=20121204

# My position

# Actual position
#LAT0=46.15
#LONG0=13.21


# ROME
LAT0=41.90892
LONG0=12.481728


#################################################################


distance () {
	pi="3.141592653589793"
        lat_1="$1"
        lon_1="$2"
        lat_2="$3"
        lon_2="$4"
        distance=`echo "s($lat_1 * 0.0174532925) * s($lat_2 * 0.0174532925) + c($lat_1 * 0.0174532925) * c($lat_2 * 0.0174532925) * c(($lon_2 - $lon_1) * 0.0174532925)"| bc -l`
        distance=`echo "($pi / 2 - a($distance / sqrt(1 - $distance * $distance))) * 6370.6934842" | bc -l `
        echo $distance
}

add_distance () {
    OFS="$IFS"
    IFS=$'\n'
    for i in `echo "$1"`
    do
	LAT=`echo "$i" | awk -F\; '{ print $4 }'`
	LONG=`echo "$i" | awk -F\; '{ print $5 }'`
	DIST=`distance $LAT0 $LONG0 $LAT $LONG | awk -v OFMT=%.1f '{ print $1+c }'`
	echo "$DIST km;$i;"
    done
    IFS="$OFS"
}

ingv () {
    curl http://cnt.rm.ingv.it/ 2> /dev/null | grep ^"<td\|</tr>" | tr '\n' ' ' | sed 's/<\/tr>/\n/g' | sed 's/<\/td>\|&nbsp;//g' | sed 's/\ \ <td>\|\ <td>\|\ <td\ width=\"45px\">/;/g'| head -n$NEVENTS | sed 's/\ ;//g' | sed 's/;;/;/g' | sed 's/;//' | grep -v ^" " | awk -F\; '{ print $2";"$3"; "$7";"$4";"$5";"$8";INGV" }'| sed 's/\//-/g' | sed 's/\ M[lL]:/ML\ /g'| sed 's/\ M[wW]:/MW\ /g' | sed 's/\ M[dD]:/MD\ /g'| sed 's/\ M[bB]:/MB\ /g' | sed 's/_/\ /g' | sed 's/\ \;/\;/g'
}

crs () {
    curl http://rts.crs.inogs.it/it/home.html 2> /dev/null | grep strong | grep -v "</li>" | sed 's/\&#039\;/\ /g' | grep -i "var\ html_\|Depth\|\|Profondit\|Data\|Date\|Location\|Localit\|Ml:\|Local\ time\|id:" | sed 's/<br \/>\|<strong>\|<\/strong>\|var\ \|<p>//g' | tr -d '\n' | sed 's/\;/\;\n/g' | sed 's/^\ //g' | sed 's/\ +\ /\;/g' | sed 's/\ \=\ /\;/g' | sed 's/<li>//g' | tr -d '\t' | sed 's/\ +/\;/g'| tail -n$NEVENTS | awk -F";| " '{ print $16";"$17";ML "$19";"$3";"$5";"$21" "$22" "$23" "$24" "$25" "$26" "$27" "$28" "$29" "$30 }' | sed s/\'//g | sed 's/\ Id:/\;CRS\#/g' | awk -F# '{ print $1 }' | grep -v "\;\;\;" | sort -r 
}


emsc () {
    # latest 50 in mediterran region
    #wget -qO- http://www.emsc-csem.org/service/rss/rss.php?typ=emsc&min_lat=10&min_long=-30&max_long=65 

    # latest 50 worldwide
    outemsc=`wget -qO- http://www.emsc-csem.org/service/rss/rss.php?typ=emsc | sed 's/<[^>]*>/\;/g' | grep UTC | head -n$NEVENTS | sed 's/&nbsp\;&nbsp\;/\ /g' | sed 's/&nbsp\;/\ /g' | sed 's/\;\;*/;/g' | sed 's/\ \ */\ /g' | sed 's/\;\ /\;/g'| sed 's/\ \;/\;/g' | awk -F";" '{ print $8";"$7";"$19";"$20";"$15";EMSC" }' | sed 's/\ N\;/\;/g' | sed 's/\ E\;/\;/g'| sed 's/\ S\;/\;/g' | sed 's/\ W\;/\;/g' | sed 's/\;[mM][bB]\ /\;MB\ /g'| sed 's/\;[mM][lL]\ /\;ML\ /g'| sed 's/\;[mM][wW]\ /\;MW\ /g'  `
    echo "$outemsc" | awk -F";" '{ printf ";"$2";"$3";"$4";"$5";"$6";"$7"ENDEND" system("date +%Y-%m-%d#%H:%M:%S -d \""$1 "\" " ); }' | sed 's/#/\;/' | tr -d '\n' | sed 's/ENDEND/\n/g' | sed 's/^0//'
}

usgs () {
#    wget -qO- http://earthquake.usgs.gov/earthquakes/feed/csv/2.5/month
    outusgs=`wget -qO- http://earthquake.usgs.gov/earthquakes/feed/csv/2.5/week 2> /dev/null | grep -v EqId | head -n$NEVENTS |  awk -F" |," '{ print $9"-"$6"-"$7";"$10" "$11";ML "$14";"$12";"$13";"$17" "$18" "$19" "$20" "$21" "$22" "$23" "$24" "$25";USGS" }' | sed 's/\"//g' | sed 's/\ \ \;/\;/g' | sed 's/\ \;/\;/g'`
    arrMonth[1]="January"
    arrMonth[2]="February"
    arrMonth[3]="March"
    arrMonth[4]="April"
    arrMonth[5]="May"
    arrMonth[6]="June"
    arrMonth[7]="July"
    arrMonth[8]="August"
    arrMonth[9]="September"
    arrMonth[10]="October"
    arrMonth[11]="November"
    arrMonth[12]="December"
    for i in `seq 1 12`
    do
	outusgs=`echo "$outusgs" | sed s/"${arrMonth[$i]}"/"$i"/g `
    done
    echo "$outusgs" | awk -F";" '{ printf ";"$3";"$4";"$5";"$6";"$7";ENDEND" system("date +%Y-%m-%d#%H:%M:%S -d \""$1" "$2 "\" " ); }' | sed 's/#/\;/' | tr -d '\n' | sed 's/ENDEND/\n/g' | sed 's/^0//'
}




#############################################################################
# main

if [ "$1" == "" ]
then
    echo "Earthquakes version 20121115."
    echo " Syntax:"
    echo 
    echo "  earthquakes.sh all|crs|ingv|emsc|usgs MaxNumEvents"
    echo
    echo "  (if not specified, MaxNumEvents = 20. Maximum is 50 )"
    exit 0
fi


A=""
B=""
C=""
D=""

# maximum number of events
lastent=`echo $@ | awk '{ print $NF }'`
case $lastent in
    ''|*[!0-9]*) NEVENTS=20  ;;
    *) NEVENTS=$lastent ;;
esac

if echo $@ | grep -i "crs\|all" > /dev/null
then
    A=`crs`
fi

if echo $@ | grep -i "ingv\|all" > /dev/null
then
    B=`ingv`
fi

if echo $@ | grep -i "emsc\|all" > /dev/null
then
    C=`emsc`
fi

if echo $@ | grep -i "usgs\|all" > /dev/null
then
    D=`usgs`
fi


list=`echo "$A" "$B" "$C" "$D" | sort -r`

# DISTANCE DATE HOUR MAGNITUDO LAT LONG LOCATION PROVIDER
# add distance to the events list

if [ "$list" != "   " ]
then
    OFS="$IFS"
    IFS=$'\n'
    for line in `echo "$list" | head -n$NEVENTS`
    do
	RESULT=`add_distance "$line" `
	# output in csv format separated by ;
	#echo "$RESULT" | sed 's/\;\;*/;/g'
	
	# maemo output
	echo "$RESULT" | awk -F\; '{ print $1" "$2" "$3" "$4" - "$7" *"$8 }'
	
	# or ordered by distance
	# echo "$RESULT" | sed 's/\;\;*/;/g' | sort -n
    done
    IFS="$OFS"
fi
